@@ -21,17 +21,11 @@ class neuralsampler:
         lr = args.lr
         weight_decay = args.weight_decay
         critic_weight_decay = args.critic_weight_decay
-        save = args.save
         viz_freq = args.viz_freq
         d_iters = args.d_iters
         g_iters = args.g_iters
         l2 = args.l2
-        r = args.r
-        sd = args.sd
-        n_comp = args.n_comp
-        z_dim = args.z_dim
         lr_D = args.lr_D
-        out_dim = args.out_dim
         hid_dim = args.hid_dim
         model = args.model
         dim = args.dim
@@ -45,6 +39,8 @@ class neuralsampler:
         mmd_two_sample = args.mmd_two_sample
         mmd_beta = args.mmd_beta
         G_loss = args.G_loss
+        disc_zero = args.disc_zero
+        log_freq = args.log_freq
         #endregion
 
         D = SmallMLP(dim, n_hid=hid_dim, n_out=1, UseSpectral=use_spectrum)
@@ -88,17 +84,11 @@ class neuralsampler:
         self.lr = lr
         self.weight_decay = weight_decay
         self.critic_weight_decay = critic_weight_decay
-        self.save = save
         self.viz_freq = viz_freq
         self.d_iters = d_iters
         self.g_iters = g_iters
         self.l2 = l2
-        self.r = r
-        self.sd = sd
-        self.n_comp = n_comp
-        self.z_dim = z_dim
         self.lr_D = lr_D
-        self.out_dim = out_dim
         self.hid_dim = hid_dim
         self.model = model
         self.dim = dim
@@ -112,6 +102,8 @@ class neuralsampler:
         self.mmd_two_sample = mmd_two_sample
         self.mmd_beta = mmd_beta
         self.G_loss = G_loss
+        self.disc_zero = disc_zero
+        self.log_freq = log_freq
         #endregion
 
 
@@ -139,6 +131,8 @@ class neuralsampler:
         mmd_two_sample = self.mmd_two_sample
         mmd_beta = self.mmd_beta
         G_loss = self.G_loss
+        disc_zero = self.disc_zero
+        log_freq = self.log_freq
         #endregion
 
         G.train()
@@ -238,8 +232,6 @@ class neuralsampler:
                 else: 
                     raise NotImplementedError("hard to move outside: because the importance ratio is not matched in scale: one is one, the other is ratio")
 
-            disc_zero = _.get_value('disc_zero')
-
             # lipschitz for Discriminator 
             D_grad = keep_grad(  D(x).sum(), x)
 
@@ -288,11 +280,11 @@ class neuralsampler:
 
                 if model == 'dw': 
                     # TODO: change this to the init data 
-                    x = np.arange(-4.0, 4.0, 0.1)
-                    y = np.arange(-4.0, 4.0, 0.1)
+                    x = np.arange(-5.0, 5.0, 0.1)
+                    y = np.arange(-5.0, 5.0, 0.1)
 
                     _X, _Y = np.meshgrid(x, y)
-                    z0 = np.concatenate([_X.reshape(-1, 1), _Y.reshape(-1, 1)], axis=1)
+                    z0 = np.concatenate([_X.reshape(-1, 1), _Y.reshape(-1, 1),  np.zeros((_Y.reshape(-1, 1).shape[0], dim -2))], axis=1)
                     # assert dim == 2
                     # need to consider how these goes to high dimension 
                     z0 = torch.tensor(z0, requires_grad=True).float().to(device)
@@ -342,7 +334,6 @@ class neuralsampler:
                     Z_list.append(zi)
                     D_list.append(di)
                     
-            log_freq = _.get_value('log_freq')
             if itr % log_freq == 0: 
                 # log the nn checkpoint 
                 model_path = os.path.join(exp_dir, 'model')
